@@ -5,12 +5,14 @@ from .similarities import (
 from .matchers import ThresholdMatcher
 from .variators import Variator, Swap
 from .filters import DissimilarFilter, NonOverlappingFilter
-from .scorers import SimSumScorer, AbsoluteScorer, MinScorer, MaxScorer, RefuseToScoreException
+from .scorers import (
+    SimSumScorer, AbsoluteScorer, MinScorer, MaxScorer, RefuseToScoreException, AlterScorer
+)
 
 __all__ = [
     "NoopIndex", "ColumnsIndex", "JaroWinklerSimilarity", "StringSimilarity",
     "DateSimilarity", "ThresholdMatcher", "MultiIndex", "Variator", "Swap",
     "DissimilarFilter", "NonOverlappingFilter", "AbsoluteNumericalSimilarity",
     "RelativeNumericalSimilarity",
-    "SimSumScorer", "AbsoluteScorer", "MinScorer", "MaxScorer", "RefuseToScoreException"
+    "SimSumScorer", "AbsoluteScorer", "MinScorer", "MaxScorer", "RefuseToScoreException", "AlterScorer"
 ]
